summaryrefslogtreecommitdiff
path: root/modules
diff options
context:
space:
mode:
authorDries Buytaert <dries@buytaert.net>2010-04-09 12:24:53 +0000
committerDries Buytaert <dries@buytaert.net>2010-04-09 12:24:53 +0000
commit459d623467a23d8deda42620eb9be7992d5cfd24 (patch)
treed4807ff4cfccd52634e7c0785649e1eae52708cd /modules
parent70d60fb88fb90a84fa06de5dff97c16dc3b43956 (diff)
downloadbrdo-459d623467a23d8deda42620eb9be7992d5cfd24.tar.gz
brdo-459d623467a23d8deda42620eb9be7992d5cfd24.tar.bz2
- Patch #445130 by Rob Loach, aspilicious: namespace the Drupal jQuery functions.
Diffstat (limited to 'modules')
-rw-r--r--modules/block/block.js14
-rw-r--r--modules/menu/menu.js2
-rw-r--r--modules/node/content_types.js6
-rw-r--r--modules/node/node.js6
-rw-r--r--modules/path/path.js2
5 files changed, 15 insertions, 15 deletions
diff --git a/modules/menu/menu.js b/modules/menu/menu.js
index a6eac4b67..c7041bbdf 100644
--- a/modules/menu/menu.js
+++ b/modules/menu/menu.js
@@ -4,7 +4,7 @@
Drupal.behaviors.menuFieldsetSummaries = {
attach: function (context) {
- $('fieldset.menu-link-form', context).setSummary(function (context) {
+ $('fieldset.menu-link-form', context).drupalSetSummary(function (context) {
if ($('#edit-menu-enabled', context).attr('checked')) {
return Drupal.checkPlain($('#edit-menu-link-title', context).val());
}
diff --git a/modules/node/content_types.js b/modules/node/content_types.js
index ed4fe81d3..a76240c78 100644
--- a/modules/node/content_types.js
+++ b/modules/node/content_types.js
@@ -4,13 +4,13 @@
Drupal.behaviors.contentTypes = {
attach: function (context) {
// Provide the vertical tab summaries.
- $('fieldset#edit-submission', context).setSummary(function(context) {
+ $('fieldset#edit-submission', context).drupalSetSummary(function(context) {
var vals = [];
vals.push(Drupal.checkPlain($('#edit-title-label', context).val()) || Drupal.t('Requires a title'));
vals.push(Drupal.checkPlain($('#edit-body-label', context).val()) || Drupal.t('No body'));
return vals.join(', ');
});
- $('fieldset#edit-workflow', context).setSummary(function(context) {
+ $('fieldset#edit-workflow', context).drupalSetSummary(function(context) {
var vals = [];
$("input[name^='node_options']:checked", context).parent().each(function() {
vals.push(Drupal.checkPlain($(this).text()));
@@ -20,7 +20,7 @@ Drupal.behaviors.contentTypes = {
}
return vals.join(', ');
});
- $('fieldset#edit-display', context).setSummary(function(context) {
+ $('fieldset#edit-display', context).drupalSetSummary(function(context) {
var vals = [];
$('input:checked', context).next('label').each(function() {
vals.push(Drupal.checkPlain($(this).text()));
diff --git a/modules/node/node.js b/modules/node/node.js
index 4a0c49d63..2f3f56f84 100644
--- a/modules/node/node.js
+++ b/modules/node/node.js
@@ -4,20 +4,20 @@
Drupal.behaviors.nodeFieldsetSummaries = {
attach: function (context) {
- $('fieldset#edit-revision-information', context).setSummary(function (context) {
+ $('fieldset#edit-revision-information', context).drupalSetSummary(function (context) {
return $('#edit-revision', context).is(':checked') ?
Drupal.t('New revision') :
Drupal.t('No revision');
});
- $('fieldset#edit-author', context).setSummary(function (context) {
+ $('fieldset#edit-author', context).drupalSetSummary(function (context) {
var name = $('#edit-name').val(), date = $('#edit-date').val();
return date ?
Drupal.t('By @name on @date', { '@name': name, '@date': date }) :
Drupal.t('By @name', { '@name': name });
});
- $('fieldset#edit-options', context).setSummary(function (context) {
+ $('fieldset#edit-options', context).drupalSetSummary(function (context) {
var vals = [];
$('input:checked', context).parent().each(function () {
diff --git a/modules/path/path.js b/modules/path/path.js
index f37421b58..e065d94b5 100644
--- a/modules/path/path.js
+++ b/modules/path/path.js
@@ -4,7 +4,7 @@
Drupal.behaviors.pathFieldsetSummaries = {
attach: function (context) {
- $('fieldset#edit-path', context).setSummary(function (context) {
+ $('fieldset#edit-path', context).drupalSetSummary(function (context) {
var path = $('#edit-path-alias').val();
return path ?
diff --git a/modules/block/block.js b/modules/block/block.js
index eb2dcc19a..4647ee4e0 100644
--- a/modules/block/block.js
+++ b/modules/block/block.js
@@ -6,14 +6,14 @@
*/
Drupal.behaviors.blockSettingsSummary = {
attach: function (context) {
// The setSummary method required for this behavior is not available
// on the Blocks administration page, so we need to make sure this
- // behavior is processed only if setSummary is defined.
- if (typeof jQuery.fn.setSummary == 'undefined') {
+ // behavior is processed only if drupalSetSummary is defined.
+ if (typeof jQuery.fn.drupalSetSummary == 'undefined') {
return;
}
- $('fieldset#edit-path', context).setSummary(function (context) {
+ $('fieldset#edit-path', context).drupalSetSummary(function (context) {
if (!$('textarea[name="pages"]', context).val()) {
return Drupal.t('Not restricted');
}
@@ -22,7 +22,7 @@ Drupal.behaviors.blockSettingsSummary = {
}
});
- $('fieldset#edit-node-type', context).setSummary(function (context) {
+ $('fieldset#edit-node-type', context).drupalSetSummary(function (context) {
var vals = [];
$('input[type="checkbox"]:checked', context).each(function () {
vals.push($.trim($(this).next('label').text()));
@@ -33,7 +33,7 @@ Drupal.behaviors.blockSettingsSummary = {
return vals.join(', ');
});
- $('fieldset#edit-role', context).setSummary(function (context) {
+ $('fieldset#edit-role', context).drupalSetSummary(function (context) {
var vals = [];
$('input[type="checkbox"]:checked', context).each(function () {
vals.push($.trim($(this).next('label').text()));
@@ -44,7 +44,7 @@ Drupal.behaviors.blockSettingsSummary = {
return vals.join(', ');
});
- $('fieldset#edit-user', context).setSummary(function (context) {
+ $('fieldset#edit-user', context).drupalSetSummary(function (context) {
var $radio = $('input[name="custom"]:checked', context);
if ($radio.val() == 0) {
return Drupal.t('Not customizable');
@@ -6,14 +6,14 @@
Drupal.behaviors.blockSettingsSummary = {
attach: function (context) {
- // The setSummary method required for this behavior is not available
+ // The drupalSetSummary method required for this behavior is not available
// on the Blocks administration page, so we need to make sure this